#!/usr/bin/perl -w
# $Id: graphdefang.pl,v 1.4 2002/09/27 21:12:12 jpk Exp $
#
# GraphDefang -- a set of tools to create graphs of your mimedefang
#                spam and virus logs.
#
# Written by:    John Kirkland
#                jpk@bl.org
#
# Copyright (c) 2002, John Kirkland
#=============================================================================

use strict;
require ("./graphdefanglib.pl");


# Location of incoming log files

my $SPAM_LOG = "/var/log/mimedefang/spamstats";
my $VIRUS_LOG = "/var/log/mimedefang/virusstats";

#print STDERR "Processing spam file\n";

my %SpamLog = read_data($SPAM_LOG)
        or die "Cannot read data from spamlog.txt";

#print STDERR "Processing virus file\n";

my %VirusLog = read_data($VIRUS_LOG)
        or die "Cannot read data from viruslog.txt";

# Create graphs

my @GraphTimes = ("hourly","daily","monthly"); 

#
# Create a line chart summary for spam and viruses.
#

my %GraphSettings = (
                "type"          => "line",              # stacked_bar, line
                "spam"          => "1",                 # Do we use spam data for this graph
                "virus"         => "1",                 # Do we use virus data for this graph
                "accumulate"    => "summary",           # What value to we accumulate and used for filenames
                "topN"          => "0",                 # Limit the max number of accumulated value (0=off)
                );
foreach my $time (@GraphTimes) {
	$GraphSettings{time} = $time;
	calculate(\%GraphSettings,\%SpamLog,\%VirusLog);
}

#
# Create a stacked bar virus chart by virus name
#

%GraphSettings = ();
%GraphSettings = (
                "type"          => "stacked_bar",               # stacked_bar, line
                "spam"          => "0",                 # Do we use spam data for this graph
                "virus"         => "1",                 # Do we use virus data for this graph
                "accumulate"    => "virusname",         # What value to we accumulate and used for filenames
                "topN"          => "0",                 # Limit the max number of accumulated value (0=off)
                );
foreach my $time (@GraphTimes) {
	$GraphSettings{time} = $time;
	calculate(\%GraphSettings,\%SpamLog,\%VirusLog);
}

#
# Create a top 9 stacked bar spam chart by recipient
#

%GraphSettings = ();
%GraphSettings = (
                "type"          => "stacked_bar",               # stacked_bar, line
                "spam"          => "1",                 # Do we use spam data for this graph
                "virus"         => "0",                 # Do we use virus data for this graph
                "accumulate"    => "recipient",         # What value to we accumulate and used for filenames
                "topN"          => "9",                 # Limit the max number of accumulated value (0=off)
                );
foreach my $time (@GraphTimes) {
	$GraphSettings{time} = $time;
	calculate(\%GraphSettings,\%SpamLog,\%VirusLog);
}

#
# Create a top 9 stacked bar spam and virus chart by recipient
#

%GraphSettings = ();
%GraphSettings = (
                "type"          => "stacked_bar",       # stacked_bar, line
                "spam"          => "1",                 # Do we use spam data for this graph
                "virus"         => "1",                 # Do we use virus data for this graph
                "accumulate"    => "recipient",         # What value to we accumulate and used for filenames
                "topN"          => "9",                 # Limit the max number of accumulated value (0=off)
                );
foreach my $time (@GraphTimes) {
	$GraphSettings{time} = $time;
	calculate(\%GraphSettings,\%SpamLog,\%VirusLog);
}

#
# Create a top 9 stacked bar spam chart by sender
#

%GraphSettings = ();
%GraphSettings = (
                "type"          => "stacked_bar",       # stacked_bar, line
                "spam"          => "1",                 # Do we use spam data for this graph
                "virus"         => "0",                 # Do we use virus data for this graph
                "accumulate"    => "sender",         # What value to we accumulate and used for filenames
                "topN"          => "9",                 # Limit the max number of accumulated value (0=off)
                );
foreach my $time (@GraphTimes) {
	$GraphSettings{time} = $time;
	calculate(\%GraphSettings,\%SpamLog,\%VirusLog);
}
